/*****************************************************************************/
/* Wii Nunchuck Interface                                                    */
/* Author: Joao Geada							Version: 1.0	March 2009   */
/* Copyright (c) 2009, Joao Geada           See end of file for terms of use */
/*****************************************************************************/

#ifndef WII_NUNCHUCK_H_
#define WII_NUNCHUCK_H_

// nunchuck cable has 4 wires
//  green: connect to SDA_PIN (pinSDA arg of Nunchuck_init funcion)
// yellow: connect to SCL_PIN (pinSCL arg of Nunchuck_init funcion)
//  black: connect to GND
//    red: connect to 5v

typedef struct {
  char  joyX;    // joystick X position (8 bits)
  char  joyY;    // joystick Y position (8 bits)
  char  buttonC; // 1 if button C pressed, 0 otherwise
  char  buttonZ; // 1 if button Z pressed, 0 otherwise
  short accelX;  // X accelerometer data (10 bits)
  short accelY;  // X accelerometer data (10 bits)
  short accelZ;  // X accelerometer data (10 bits)
} NunchuckDatT;

/** initialize a Wii nunchuck on the i2c bus
  * pinSDA:	   i2c data pin --> connect to the green wire in Nunchuck cable
  * pinSCL:    i2c clock pin --> connect to the yellow wire
  * The red wire in the nunchuck cable should be connected to +5v,
  * the black wire should be connected to Gnd.
  */
int Nunchuck_init(int pinSDA, int pinSCL);

/** read in the current Wii nunchuck sensor data
  * and store it into the datastructure "nd"
  */
int Nunchuck_read(NunchuckDatT *nd);

/*
+------------------------------------------------------------------------------------------------------------------------------+
                                                   TERMS OF USE: MIT License                                                                                                              
+------------------------------------------------------------------------------------------------------------------------------
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation     
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,    
modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
is furnished to do so, subject to the following conditions:                                                                   
                                                                                                                              
The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
                                                                                                                              
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE          
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR         
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,   
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                         
+------------------------------------------------------------------------------------------------------------------------------+
*/

#endif