/*****************************************************************************/
/* Wii Nunchuck Interface test example                                       */
/* Author: Joao Geada							Version: 1.0	March 2009   */
/* Copyright (c) 2009, Joao Geada           See end of file for terms of use */
/*****************************************************************************/

#include "WiiNunchuck.h"
#include <stdio.h>
#include <propeller.h>
#include "FdSerial.h"


// nunchuck cable has 4 wires
//  green: connect to SDA_PIN
// yellow: connect to SCL_PIN
//  black: connect to GND
//    red: connect to 5v (NOTE: it also works connected to 3.3V)
#define SCL_PIN 28
#define SDA_PIN 29

#define SERIAL_TX   30
#define SERIAL_RX   31

#define SERIAL_BAUD 57600

/*
 * get a character from serial interface
 */
int getchar(void)
{
    return FdSerial_rx();
}
/*
 * check for character input without blocking
 */
int getkey(void)
{
    return FdSerial_rxcheck();
}

/*
 * putchar must be defined for printf to work
 */
int putchar(char ch)
{
    if(ch == '\n') FdSerial_tx('\r');
    FdSerial_tx(ch);
    return ch;
}

void main()
{
   int status;
   char rc;
   NunchuckDatT ncd;
   FdSerial_start(SERIAL_RX,SERIAL_TX,0,SERIAL_BAUD);
   FdSerial_rx(); // wait for input character before starting up nunchuck
   printf("\nPropeller running at: %d KHz\n", CLKFREQ/1000);
   status = Nunchuck_init(SDA_PIN, SCL_PIN);
   printf("Nunchuck status: %d\n\n", status);
   status = 0;
   while(1) {
      rc = Nunchuck_read(&ncd);
	  printf("Sequence: %d -> %d\n", status++, rc);
	  printf("   Joy X: %d\n", ncd.joyX);
	  printf("   Joy Y: %d\n", ncd.joyY);
	  printf("Button C: %d\n", ncd.buttonC);
	  printf("Button Z: %d\n", ncd.buttonZ);
	  printf(" Accel X: %d\n", ncd.accelX); 
	  printf(" Accel Y: %d\n", ncd.accelY); 
	  printf(" Accel Z: %d\n", ncd.accelZ);
	  printf("\n\n"); 
   	  FdSerial_rx(); // wait for input character before looping again
   }
}

/*
+------------------------------------------------------------------------------------------------------------------------------+
                                                   TERMS OF USE: MIT License                                                                                                              
+------------------------------------------------------------------------------------------------------------------------------
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation     
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,    
modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
is furnished to do so, subject to the following conditions:                                                                   
                                                                                                                              
The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
                                                                                                                              
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE          
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR         
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,   
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                         
+------------------------------------------------------------------------------------------------------------------------------+
*/